@@ -231,7 +231,7 @@ def add_options(option_parser):
     )
     start_finding_options.add_option(
         "--starts-per-motif",
-        default=3,
+        default=4,
         type='int',
         help="Number of starts to find per motif."
     )
@@ -1646,7 +1646,11 @@ class MotifFinder(object):
         # sort the motifs to find the best one and make a logo for it.
         #
         if not start_results:
-            raise RuntimeError('Could not find any starts in the data for these parameter settings.')
+            logger.warning(
+                "Could not find any starts in the data for these parameter settings. "
+                "You could try increasing the '--starts-per-motif' option"
+            )
+            return None
         start_results.sort()
         best = start_results[0]
         best_model = best.em_result.model
@@ -2259,7 +2263,9 @@ class Algorithm(object):
         with Timer(msg='find motifs') as timer:
             self.motifs = []
             for _motif_idx in xrange(self.options.num_motifs):
-                self._find_motif()
+                if not self._find_motif():
+                    # We couldn't find a motif, perhaps we ran out of starts
+                    break
             self.timings.append((timer._msg, timer.timer.duration()))
         
 
@@ -2272,8 +2278,10 @@ class Algorithm(object):
             #
             motif_finder = self.create_motif_finder(motif_idx)
             motif = motif_finder(self.start_finder)
-            self.motifs.append(motif)
-            self.output_motif(motif, seconds_taken=timer.timer.duration())
+            if None != motif:
+                self.motifs.append(motif)
+                self.output_motif(motif, seconds_taken=timer.timer.duration())
+            return motif
     
     
     def _tomtom(self):
